function JR_MRI_TV_wrapper(sampling, alpha, beta)
% JR_MRI_TV_wrapper
%   JR_MRI_TV_wrapper(sampling, alpha, beta) is a wrapper for JR_MRI_TV. 
% It loads the data, runs the algorithms and saves the results
% 
% Input:    
%   sampling [string]       
%       used to read the data and to write the solution
%
%   alpha [scalar]              
%       an overall scaling for the prior
%
%   beta [scalar]              
%       "smoothing" to make the prior differentiable
%
% See also: JR_MRI_TV
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% -------------------------------------------------------------------------

    name = ['JR_MRI_' sampling '_TV'];
    run(fullfile('..', 'data', ['JR_data_' sampling '.m']));
    folder_results = fullfile('..', 'results', name);
    mkdir(folder_results);

    % Rec
    param = [alpha beta];
    [solution, converged, parts] = JR_MRI_TV(options{index.misc}.size, param, data{index.mri}, ...
        operator{index.mri}, adjoint{index.mri});

    err = JR_error(solution, ground_truth{index.mri});

    JR_save_results(err, converged, solution, param, parts, {'TV alpha', 'TV beta'}, ...
        ground_truth{index.mri}, [folder_results '/' name], 'MRI');
    
end