function JR_PET_wrapper(n_iterations)
% JR_PET_wrapper
%   R_PET_wrapper(n_iterations) is a wrapper for JR_PET. 
% It loads the data, runs the algorithms and saves the results
% 
% Input:    
%   n_iterations [int]       
%       number of MLEM iterations
%
% See also: JR_PET
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% -------------------------------------------------------------------------

    name = 'JR_PET';
    run(fullfile('..', 'data', 'JR_data.m'));
    folder_results = fullfile('..', 'results', name);
    mkdir(folder_results);

    % Rec
    [solution, converged, parts] = JR_PET(options{index.misc}.size, data{index.pet}, ...
        operator{index.pet}, adjoint{index.pet}, n_iterations);
    
    err = JR_error(solution, ground_truth{index.pet});

    JR_save_results(err, converged, solution, n_iterations, parts, {'#iterations'}, ...
        ground_truth{index.pet}, [folder_results '/' name], 'PET');
    
end