function s = JR_error(x, x0)
% JR_error
%   s = JR_error(x, x0) computes the relative l2-error of x compared to x0
% on the region of interest (defined by JR_ROI) and on the whole phantom. 
%
% Input:    
%   x [matrix or vector]              
%       image to be evaluated
%
%   x0 [matrix or vector]       
%
% Output:
%   s [vector]
%       relative l2-error on the region of interest and the whole phantom.
%
% See also: JR_ROI
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% -------------------------------------------------------------------------

    s(1) = JR_rel_l2(x,x0,JR_ROI);
    s(2) = JR_rel_l2(x,x0);

end