function U = JR_extent_x(u, boundary_condition)
% JR_extent_x
%   U = JR_extent_x(u, boundary_condition, boundary_length) extents the 
% image u at the boundary according to the boundary condition.
%
% Input:    
%   u [matrix]              
%       scalar valued function
%
%   boundary_condition [string]              
%       either 'zero' or 'constant'
%
% Output:
%   U [matrix]
%       extended input
%
% See also: JR_partial_derivative_x JR_gradient
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% -------------------------------------------------------------------------
       
    U = zeros(size(u) + [2 0]);
    U(2:end-1,:) = u;
            
    switch boundary_condition
        case 'zero'
        case 'constant'
            U(1,:)   = u(1,:);
            U(end,:) = u(end,:);
        otherwise
            error('Choice of boundary condition unavailable: %s', boundary_condition)
    end
    
end