function s = JR_joint_error(z, x0, y0)
% JR_joint_error
%   s = JR_joint_error(z, x0, y0) computes the errors of the joint image z
% to the separated "ground truth" images x0 and y0.
%
% Input:    
%   z [cell]              
%       vector-valued image
%
%   x0 [matrix]              
%       vector-valued image
%
%   y0 [matrix]              
%       vector-valued image
%
% Output:
%   s [vector]
%       s(1):   mean relative error over the region of interest of the 
%               input to the ground truths
%       s(2):   relative error over the region of interest of the first 
%               input (PET) to x0
%       s(3):   relative error over the whole phantom of the first input 
%               (PET) to x0
%       s(4):   relative error over the region of interest of the second 
%               input (PET) to y0
%       s(5):   relative error over the whole phantom of the second input 
%               (PET) to y0
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% -------------------------------------------------------------------------

    x = z{1};
    y = z{2};

    s1 = JR_error(x, x0);
    s2 = JR_error(y, y0);

    s = zeros(5,1);
    s(1) = .5*(s1(1) + s2(1));
    s(2:3) = s1;
    s(4:5) = s2;
    
end