function images = JR_vector2images(x, s_image, I)
% JR_vector2images
%   images = JR_vector2images(x, s_image, I) takes a vector x and reshapes it
% into a cell array of images of size size_image. It reverts the
% JR_images2vector operation.
% 
% Input: 
%   x [vector]              
%       input vector to be reshaped
%
%   s_image [vector]              
%       the size of the images
%
%   I [vector]              
%       a cell array with the indices of all images
%
% Output:
%   images [cell]              
%       cell array of equal size images
%
% See also: JR_images2vector
%
% 2014-08-06 --------------------------------------------------------------
% Matthias J. Ehrhardt
% CMIC, University College London, UK 
% matthias.ehrhardt.11@ucl.ac.uk
% http://www.cs.ucl.ac.uk/staff/ehrhardt/software.html
%
% -------------------------------------------------------------------------
% Copyright 2014 University College London
%
% Licensed under the Apache License, Version 2.0 (the "License");
% you may not use this file except in compliance with the License.
% You may obtain a copy of the License at
%
%   http://www.apache.org/licenses/LICENSE-2.0
%
% Unless required by applicable law or agreed to in writing, software
% distributed under the License is distributed on an "AS IS" BASIS,
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
% See the License for the specific language governing permissions and
% limitations under the License.
% -------------------------------------------------------------------------
 
    if numel(s_image) == 1; s_image = s_image * [1 1]; end;

    if nargin > 2 && numel(I) > 0
        K = length(I);    
        images = cell(K,1);

        for k = 1 : K
            images{k} = reshape(x(I{k}), s_image);
        end    
    else        
        M = prod(s_image);
        K = numel(x)/M;
        images = cell(K,1);
        
        for k = 1 : K
            images{k} = reshape(x((k-1)*M + (1:M)), s_image);
        end
    end    
    
end